==> haskell-data-clist-0.1.2.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-clist
version: 0.1.2.1
id: data-clist-0.1.2.1-LPOgLoVJGluEEHpPTpJ6T8
key: data-clist-0.1.2.1-LPOgLoVJGluEEHpPTpJ6T8
license: BSD3
maintainer: Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>
stability: experimental
homepage: https://github.com/sw17ch/data-clist
synopsis: Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.
category: Data Structures
author: John Van Enk <vanenkj@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.CircularList
abi: 7bd005f889fa958411bf3ace54117cfb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-clist-0.1.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-clist-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/data-clist-0.1.2.1
hs-libraries: HSdata-clist-0.1.2.1-LPOgLoVJGluEEHpPTpJ6T8
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    deepseq-1.4.3.0
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html: /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-clist-0.1.2.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-clist
version: 0.1.2.1
id: data-clist-0.1.2.1-JQwK0J4X8cELKfb0PagR1V
key: data-clist-0.1.2.1-JQwK0J4X8cELKfb0PagR1V
license: BSD-3-Clause
maintainer: Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>
author: John Van Enk <vanenkj@gmail.com>
stability: experimental
homepage: https://github.com/sw17ch/data-clist
synopsis: Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.
category: Data Structures
abi: 85a7a260ba6507ed53ba49e7d137b01a
exposed: True
exposed-modules:
    Data.CircularList
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-clist-0.1.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-clist-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/data-clist-0.1.2.1
hs-libraries: HSdata-clist-0.1.2.1-JQwK0J4X8cELKfb0PagR1V
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    deepseq-1.4.3.0
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html: /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
